@@ -14,9 +14,10 @@
 
 import mock
 
+from ..helpers import make_connection
+
 from .helpers import _Base
 from .helpers import _make_client
-from .helpers import _make_connection
 
 
 class TestCopyJobConfig(_Base):
@@ -333,7 +334,7 @@ class TestCopyJob(_Base):
         del RESOURCE["etag"]
         del RESOURCE["selfLink"]
         del RESOURCE["user_email"]
-        conn = _make_connection(RESOURCE)
+        conn = make_connection(RESOURCE)
         client = _make_client(project=self.PROJECT, connection=conn)
         source = self._table_ref(self.SOURCE_TABLE)
         destination = self._table_ref(self.DESTINATION_TABLE)
@@ -396,9 +397,9 @@ class TestCopyJob(_Base):
             "writeDisposition": WriteDisposition.WRITE_TRUNCATE,
         }
         RESOURCE["configuration"]["copy"] = COPY_CONFIGURATION
-        conn1 = _make_connection()
+        conn1 = make_connection()
         client1 = _make_client(project=self.PROJECT, connection=conn1)
-        conn2 = _make_connection(RESOURCE)
+        conn2 = make_connection(RESOURCE)
         client2 = _make_client(project=self.PROJECT, connection=conn2)
         source = self._table_ref(self.SOURCE_TABLE)
         destination = self._table_ref(self.DESTINATION_TABLE)
@@ -427,7 +428,7 @@ class TestCopyJob(_Base):
 
     def test_exists_miss_w_bound_client(self):
         PATH = "/projects/%s/jobs/%s" % (self.PROJECT, self.JOB_ID)
-        conn = _make_connection()
+        conn = make_connection()
         client = _make_client(project=self.PROJECT, connection=conn)
 
         source = self._table_ref(self.SOURCE_TABLE)
@@ -446,9 +447,9 @@ class TestCopyJob(_Base):
 
     def test_exists_hit_w_alternate_client(self):
         PATH = "/projects/%s/jobs/%s" % (self.PROJECT, self.JOB_ID)
-        conn1 = _make_connection()
+        conn1 = make_connection()
         client1 = _make_client(project=self.PROJECT, connection=conn1)
-        conn2 = _make_connection({})
+        conn2 = make_connection({})
         client2 = _make_client(project=self.PROJECT, connection=conn2)
         source = self._table_ref(self.SOURCE_TABLE)
         destination = self._table_ref(self.DESTINATION_TABLE)
@@ -468,7 +469,7 @@ class TestCopyJob(_Base):
     def test_reload_w_bound_client(self):
         PATH = "/projects/%s/jobs/%s" % (self.PROJECT, self.JOB_ID)
         RESOURCE = self._make_resource()
-        conn = _make_connection(RESOURCE)
+        conn = make_connection(RESOURCE)
         client = _make_client(project=self.PROJECT, connection=conn)
         source = self._table_ref(self.SOURCE_TABLE)
         destination = self._table_ref(self.DESTINATION_TABLE)
@@ -488,9 +489,9 @@ class TestCopyJob(_Base):
     def test_reload_w_alternate_client(self):
         PATH = "/projects/%s/jobs/%s" % (self.PROJECT, self.JOB_ID)
         RESOURCE = self._make_resource()
-        conn1 = _make_connection()
+        conn1 = make_connection()
         client1 = _make_client(project=self.PROJECT, connection=conn1)
-        conn2 = _make_connection(RESOURCE)
+        conn2 = make_connection(RESOURCE)
         client2 = _make_client(project=self.PROJECT, connection=conn2)
         source = self._table_ref(self.SOURCE_TABLE)
         destination = self._table_ref(self.DESTINATION_TABLE)
